@@ -122,7 +122,7 @@ DINT = Int32
 def Int64(value):
     return ua.Variant(int(value), ua.VariantType.Int64)  
 LINT = Int64
-    
+
 def UInt16(value):
     return ua.Variant(int(value), ua.VariantType.UInt16) 
 UINT = UInt16
@@ -559,13 +559,16 @@ class Node:
             return data[self.key]    
     
     def _parse_value_for_ua(self, value):
+        
         if self._vtype:
             value = self._vtype(value)
         
-        if isinstance(value, (int,float)):
-            # remove embiguity between int64 and int32
+        
+        # this is a security net. In most of situation a python int will not work (LINT are rare in TwinCat FB)
+        # this shall normally not be called and should be handled by vtype at device creation
+        if isinstance(value, (int,)):
+            # remove embiguity between int64 and int32, int16
             # we need to ask the variant_type on the server
-            # TODO: I think this should be handled by vtype instead
             if self._ua_variant_type is None:
                 self._ua_variant_type = self._ua_node.get_data_type_as_variant_type()
             datavalue = ua.DataValue(ua.Variant(value, self._ua_variant_type))
