@@ -1,7 +1,7 @@
 from .device import Device, _name_attr, _inc, GROUP
 from . import keys as K
 from .manager import Manager # see at the end of file
-from .interface import nodealiasproperty
+from .interface import nodealiasproperty, Int16, Int32
 from collections import OrderedDict 
 from .tools import upload
 #                      _              _   
@@ -211,10 +211,10 @@ def axis_type(value):
         axis_type(1) == 1
     """
     try:
-        return getattr(AXIS_TYPE, value) if isinstance(value, str) else value
+        val = getattr(AXIS_TYPE, value) if isinstance(value, str) else value
     except AttributeError:
         raise ValueError('Unknown AXIS type %r'%value)
-
+    return Int32(val)
 # 
 #   __                  _   _                 
 #  / _|_   _ _ __   ___| |_(_) ___  _ __  ___ 
@@ -301,6 +301,19 @@ class MotorStatInterface(Device.StatInterface):
 class MotorCfgInterface(Device.CfgInterface):
     # we can define the type to parse value directly on the class by annotation
     axis_type : axis_type
+    tout_init: Int32 
+    tout_move: Int32        
+    tout_switch: Int32
+    init_seq1_action: Int32
+    init_seq2_action: Int32
+    init_seq3_action: Int32
+    init_seq4_action: Int32
+    init_seq5_action: Int32
+    init_seq6_action: Int32
+    init_seq7_action: Int32
+    init_seq8_action: Int32
+    init_seq9_action: Int32
+    init_seq10_action: Int32
 
 # redefine the Method interface to include the proper description of the RpcError
 class MotorRpcNode(Device.RpcInterface.RpcNode):
@@ -335,10 +348,15 @@ class Motor(Device):
     StatInterface = MotorStatInterface
     CfgInterface = MotorCfgInterface
     
-    def get_configuration(self):
+    def get_configuration(self, **kwargs):
         """  return a node/value pair dictionary ready to be uploaded 
         
         The node/value dictionary represent the device configuration. 
+        
+        Args:
+            **kwargs : name/value pairs pointing to cfg.name node
+                      This allow to change configuration on the fly
+                      without changing the config file. 
         """
         
         config = self._config 
@@ -347,6 +365,8 @@ class Motor(Device):
         # just update what is in ctrl_config, this should work for motor 
         # one may need to check parse some variable more carefully       
         cfg_dict = {self.cfg.get_node(k):v for k,v in  ctrl_config.items() }
+        cfg_dict.update({self.cfg.get_node(k):v for k,v in  kwargs.items() })
+        
         
         try:
             initialisation = config[K.INITIALISATION]
