@@ -7,7 +7,7 @@ from datetime import datetime, timedelta
 import traceback
 import sys
 
-__all__ = ['wait', 'Waiter', 'all_true', 'all_false', 'any_true', 'any_false', 'get_utc', 'local_utc', 
+__all__ = ['wait', 'Waiter', 'get_utc', 'local_utc', 
            'local_time', 'FifoNodes', 'FifoOneNode', 
             'Downloader', 'Uploader', 'Player', 'Prefixed',
             'suffix_setter', 'setitem', 'download', 'upload']
@@ -90,22 +90,23 @@ class FifoNodes(NodeAlias):
     
     Exemple:
         
-        In this exxample `local_time` is a builtin node alias returning local time 
-        The first motor is moving while the second standstill at 0.0
+    In this exxample `local_time` is a builtin node alias returning local time 
+    The first motor is moving while the second standstill at 0.0
          
-        ::
-             > from pydevmgr import local_time 
-             > nodes = [local_time, mgr.motor1.stat.pos_actual, mgr.motor2.stat.pos_actual]
-             > f = FifoNodes( "mot_poses", nodes, 20)
-             > f.get()
-             deque([(1604931613.136023, 96.44508185106795, 0.0)])
-             > f.get()
-             deque([(1604931613.136023, 96.44508185106795, 0.0),
-             (1604931614.258859, 95.32508185106808, 0.0)])
-             > f.get()
-             deque([(1604931613.136023, 96.44508185106795, 0.0),
-             (1604931614.258859, 95.32508185106808, 0.0),
-             (1604931615.451603, 94.13508185106821, 0.0)])
+    ::
+    
+        > from pydevmgr import local_time 
+        > nodes = [local_time, mgr.motor1.stat.pos_actual, mgr.motor2.stat.pos_actual]
+        > f = FifoNodes( "mot_poses", nodes, 20)
+        > f.get()
+        deque([(1604931613.136023, 96.44508185106795, 0.0)])
+        > f.get()
+        deque([(1604931613.136023, 96.44508185106795, 0.0),
+        (1604931614.258859, 95.32508185106808, 0.0)])
+        > f.get()
+        deque([(1604931613.136023, 96.44508185106795, 0.0),
+        (1604931614.258859, 95.32508185106808, 0.0),
+        (1604931615.451603, 94.13508185106821, 0.0)])
         
         
     """
@@ -216,14 +217,14 @@ def wait(node_or_func_list, logic="all_true", period=0.1, timeout=60, data=None)
     """
     Waiter(node_or_func_list, logic=logic, period=period, timeout=timeout, data=data).wait()
 
-def all_true(functions, node_get):
+def _all_true(functions, node_get):
     """ all_true(lst, nodes) -> return True if all function and node in list return True """
     for func in functions:
         if not func():
             return False
     return all( node_get() )
 
-def all_false(functions, node_get):
+def _all_false(functions, node_get):
     """ all_false(lst) -> return True if all function in the list return False """
 
     for func in functions:
@@ -231,14 +232,14 @@ def all_false(functions, node_get):
             return False
     return all( not v for v in node_get() )
     
-def any_true(functions, node_get):
+def _any_true(functions, node_get):
     """ any_true(lst) -> return True if one of the function in the list return True """
     for func in functions:
         if func():
             return True
     return any( node_get() )
 
-def any_false(functions, node_get):
+def _any_false(functions, node_get):
     """ any_false(lst) -> return True if one of the function in the list return False """
     for func in functions:
         if not func():
@@ -247,10 +248,10 @@ def any_false(functions, node_get):
 
 """ Used in wait to define the logic applied """
 _logic_loockup = {
-    "all_true"  : all_true, 
-    "all_false" : all_false, 
-    "any_true"  : any_true, 
-    "any_false" : any_false
+    "all_true"  : _all_true, 
+    "all_false" : _all_false, 
+    "any_true"  : _any_true, 
+    "any_false" : _any_false
 }
 
 
@@ -612,6 +613,9 @@ class Downloader:
     def disconnect(self, token):
         """ Disconnect the App with the given token 
         
+        All the nodes used by the app (and not by other connected app) will be removed from the 
+        download queue of nodes.
+         
         Args:
             token : a Token returned by :func:`Downloader.new_connection`
         """
@@ -630,7 +634,7 @@ class Downloader:
         self._rebuild_failure_callbacks()
     
     def add_node(self, token, *nodes):
-        """ Register nodes to be downloaded for en iddentified app
+        """ Register nodes to be downloaded for an iddentified app
         
         Args:
             token: a Token returned by :func:`Downloader.new_connection`
@@ -655,7 +659,7 @@ class Downloader:
     def add_failure_callback(self, token, *callbacks):  
         """ Add one or several callbacks to be executed when a download failed 
         
-        The callbacks must have the signature f(e) with e the error raised
+        The callbacks must have the signature f(e) with e the error grabbed
         
         Args:
             token: a Token returned by :func:`Downloader.new_connection`
